/* eslint-disable react/prop-types */
import { useState } from "react";
import { saveNote, deleteNote, editNote } from "../../assets/SvgIcons/SvgIcons";

const Card = ({ onDelete, onSave, id, content: initialContent }) => {
  const [content, setContent] = useState(initialContent || "");
  const [isEditing, setIsEditing] = useState(true);
  const [saved, setSaved] = useState(false);

  const handleSave = () => {
    onSave(id, content);
    setIsEditing(false);
    setSaved(true);
    setTimeout(() => setSaved(false), 3000);
  };

  const handleEdit = () => {
    setIsEditing(true);
  };

  return (
    <div className="max-w-xs rounded-lg border border-gray-200 bg-yellow-200 shadow-md transform transition duration-700 p-10">
      <div>
        <textarea
          value={content}
          onChange={(e) => setContent(e?.target?.value)}
          placeholder="Write your note here..."
          readOnly={!isEditing}
          className={`flex items-center justify-normal bg-yellow-200 rounded focus:outline-0 w-full p-2 placeholder-black ${
            isEditing
              ? "border-none "
              : "bg-yellow-200 cursor-not-allowed border border-gray-400"
          }`}
          //Reference
        ></textarea>
        {saved && <p className="text-green-600 text-sm mt-2">Note Saved</p>}
      </div>
      <div className="p-4">
        <div className="flex justify-between gap-4">
          {isEditing ? (
            <>
              <button
                onClick={() => {
                  handleSave();
                }}
                className="flex px-4 py-2 items-center bg-blue-600 text-white text-xs font-bold uppercase rounded hover:bg-blue-500 focus:outline-none mt-4 gap-3"
              >
                Save Note {saveNote}
              </button>
              <button
                onClick={onDelete}
                className="flex px-4 py-2 items-center bg-red-500 text-white text-xs font-bold uppercase rounded hover:bg-red-400 focus:outline-none mt-4 gap-3"
              >
                Delete Note {deleteNote}
              </button>
            </>
          ) : (
            <button
              onClick={handleEdit}
              className="flex px-4 py-2 items-center bg-gray-600 text-white text-xs font-bold uppercase rounded hover:bg-gray-500 focus:outline-none mt-4 gap-3"
            >
              Edit Note {editNote}
            </button>
          )}
        </div>
      </div>
    </div>
  );
};

export default Card;
